/***************************************************************************
                          qcupsprinter.h  -  description
                             -------------------
    begin                : Thu Jun 15 2000
    copyright            : (C) 2000 by Michael Goffioul
    email                : gofioul@imec.be
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QCUPSPRINTER_H
#define QCUPSPRINTER_H

#include <qpaintdevice.h>
#include <qstring.h>
#include <qprinter.h>
#include <cups/cups.h>

// forward declaration
class QPrinterWrapper;

/**
  *@author Michael Goffioul
  */

class QCupsPrinter : public QPaintDevice {
public:
	QCupsPrinter();
	~QCupsPrinter();

	// interface functions
	QSize margins() const;
	bool fullPage() const;
	void setFullPage(bool on);
	QString creator() const;
	void setCreator(const QString& s);
	bool outputToFile() const;
	void setOutputToFile(bool on);
	QString outputFileName() const;
	void setOutputFileName(const QString& s);
	QString docName() const;
	void setDocName(const QString& s);
	int colorMode() const;
	void setColorMode(int c);
	int pageOrder() const;
	void setPageOrder(int o);
	int orientation() const;
	void setOrientation(int o);
	int numCopies() const;
	void setNumCopies(int n);
	QString printerName() const;
	void setPrinterName(const QString& p);
	int pageSize() const;
	void setPageSize(int s);
	bool abort();
	bool aborted() const;
	bool setup(QWidget *parent = 0);
	bool newPage();

	// dummy functions
	int minPage() const;
	int maxPage() const;
	void setMinMax(int, int);
	int fromPage() const;
	int toPage() const;
	void setFromTo(int, int);
	QString printProgram() const;
	void setPrintProgram(const QString&);
	QString printerSelectionOption() const;
	void setPrinterSelectionOption(const QString&);

	// useful functions
	bool printFile(const QString& filename);
	void setDialogProperties(int p);

protected:
	bool cmd(int c, QPainter *painter, QPDevCmdParam *p);
	virtual int metric(int) const;

private:
	QString defaultPageName(const QString& printer);

private:
	QPrinterWrapper	*wrapper_;
	QString	tmpPrintFile_;
	QString	printerName_, printer_ /* complete instance name */;
	cups_option_t	*options_;
	int	num_options_;
	bool	outputToFile_;
	QString	outputFileName_;
	int	pages_;
};

#endif
